@@ -1,23 +1,21 @@
 # This file is part of Tryton.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
-from __future__ import division
 
 import datetime
 
 from sql import Literal
 from sql.aggregate import Sum
 
-from trytond.model import ModelView, ModelSQL, fields, Unique
+from trytond.model import ModelView, ModelSQL, DeactivableMixin, fields, Unique
 from trytond.pyson import Not, Bool, Eval, If
 from trytond.transaction import Transaction
 from trytond.pool import Pool
 from trytond.tools import reduce_ids, grouped_slice
-from trytond import backend
 
 __all__ = ['Work', 'WorkContext']
 
 
-class Work(ModelSQL, ModelView):
+class Work(DeactivableMixin, ModelSQL, ModelView):
     'Work'
     __name__ = 'timesheet.work'
     name = fields.Char('Name',
@@ -34,8 +32,6 @@ class Work(ModelSQL, ModelView):
             },
         depends=['name'],
         help="Use to relate the time spent to other records.")
-    active = fields.Boolean('Active',
-        help="Uncheck to exclude the work from future use.")
     duration = fields.Function(fields.TimeDelta('Timesheet Duration',
             'company_work_time', help="Total time spent on this work."),
         'get_duration')
@@ -83,8 +79,7 @@ class Work(ModelSQL, ModelView):
 
     @classmethod
     def __register__(cls, module_name):
-        TableHandler = backend.get('TableHandler')
-        table_h = TableHandler(cls, module_name)
+        table_h = cls.__table_handler__(module_name)
         table = cls.__table__()
         cursor = Transaction().connection.cursor()
 
@@ -103,7 +98,7 @@ class Work(ModelSQL, ModelView):
                 id2name[id_] = name
                 id2parent[id_] = parent
 
-            for id_, name in id2name.iteritems():
+            for id_, name in id2name.items():
                 parent = id2parent[id_]
                 while parent:
                     name = '%s\\%s' % (id2name[parent], name)
@@ -121,10 +116,6 @@ class Work(ModelSQL, ModelView):
                     where=table.timesheet_available == False))
             table_h.drop_column('timesheet_available')
 
-    @staticmethod
-    def default_active():
-        return True
-
     @staticmethod
     def default_company():
         return Transaction().context.get('company')
@@ -203,9 +194,9 @@ class Work(ModelSQL, ModelView):
     def copy(cls, works, default=None):
         if default is None:
             default = {}
-        default = default.copy()
-        if 'timesheet_lines' not in default:
-            default['timesheet_lines'] = None
+        else:
+            default = default.copy()
+        default.setdefault('timesheet_lines', None)
         return super(Work, cls).copy(works, default=default)
 
     @classmethod
